package org.jeecg.modules.clockInproject.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang3.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.exception.JeecgBootException;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.clockInproject.entity.ClockInProject;
import org.jeecg.modules.clockInproject.service.IClockInProjectService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: clock_in_project
 * @Author: jeecg-boot
 * @Date:   2024-11-05
 * @Version: V1.0
 */
@Api(tags="clock_in_project")
@RestController
@RequestMapping("/clockInproject/clockInProject")
@Slf4j
public class ClockInProjectController extends JeecgController<ClockInProject, IClockInProjectService> {
	@Autowired
	private IClockInProjectService clockInProjectService;
	
	/**
	 * 分页列表查询
	 *
	 * @param clockInProject
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "clock_in_project-分页列表查询")
	@ApiOperation(value="clock_in_project-分页列表查询", notes="clock_in_project-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ClockInProject>> queryPageList(ClockInProject clockInProject,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ClockInProject> queryWrapper = QueryGenerator.initQueryWrapper(clockInProject, req.getParameterMap());
		Page<ClockInProject> page = new Page<ClockInProject>(pageNo, pageSize);
		IPage<ClockInProject> pageList = clockInProjectService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param clockInProject
	 * @return
	 */
	@AutoLog(value = "clock_in_project-添加")
	@ApiOperation(value="clock_in_project-添加", notes="clock_in_project-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ClockInProject clockInProject) {
		if(StringUtils.isNotBlank(clockInProject.getTeamId())){
			List<ClockInProject> clockInProjects = clockInProjectService.lambdaQuery()
					.eq(ClockInProject::getDelFlag, 0)
					.eq(ClockInProject::getTeamId, clockInProject.getTeamId())
					.list();

			if(clockInProjects!= null && clockInProjects.size()!=0){
				throw new JeecgBootException("该团队已有绑定项目");
			}
		}
		clockInProjectService.save(clockInProject);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param clockInProject
	 * @return
	 */
	@AutoLog(value = "clock_in_project-编辑")
	@ApiOperation(value="clock_in_project-编辑", notes="clock_in_project-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ClockInProject clockInProject) {
		if(StringUtils.isNotBlank(clockInProject.getTeamId())){
			List<ClockInProject> clockInProjects = clockInProjectService.lambdaQuery()
					.eq(ClockInProject::getDelFlag, 0)
					.eq(ClockInProject::getTeamId, clockInProject.getTeamId())
					.list();

			if(clockInProjects!= null && clockInProjects.size()!=0){
				for (ClockInProject clockInProject1:clockInProjects){
					if(StringUtils.equals(clockInProject.getId(),clockInProject1.getId())){
						break;
					}else{
						throw new JeecgBootException("该团队已有绑定项目");
					}
				}

			}
		}
		clockInProjectService.updateById(clockInProject);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "clock_in_project-通过id删除")
	@ApiOperation(value="clock_in_project-通过id删除", notes="clock_in_project-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		clockInProjectService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "clock_in_project-批量删除")
	@ApiOperation(value="clock_in_project-批量删除", notes="clock_in_project-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.clockInProjectService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "clock_in_project-通过id查询")
	@ApiOperation(value="clock_in_project-通过id查询", notes="clock_in_project-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ClockInProject> queryById(@RequestParam(name="id",required=true) String id) {
		ClockInProject clockInProject = clockInProjectService.getById(id);
		if(clockInProject==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(clockInProject);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param clockInProject
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ClockInProject clockInProject) {
        return super.exportXls(request, clockInProject, ClockInProject.class, "clock_in_project");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ClockInProject.class);
    }

}
