package org.jeecg.modules.clockInprojectitem.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.clockInprojectitem.entity.ClockInProjectItem;
import org.jeecg.modules.clockInprojectitem.service.IClockInProjectItemService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: clock_in_project_item
 * @Author: jeecg-boot
 * @Date:   2024-11-05
 * @Version: V1.0
 */
@Api(tags="clock_in_project_item")
@RestController
@RequestMapping("/clockInprojectitem/clockInProjectItem")
@Slf4j
public class ClockInProjectItemController extends JeecgController<ClockInProjectItem, IClockInProjectItemService> {
	@Autowired
	private IClockInProjectItemService clockInProjectItemService;
	
	/**
	 * 分页列表查询
	 *
	 * @param clockInProjectItem
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "clock_in_project_item-分页列表查询")
	@ApiOperation(value="clock_in_project_item-分页列表查询", notes="clock_in_project_item-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ClockInProjectItem>> queryPageList(ClockInProjectItem clockInProjectItem,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ClockInProjectItem> queryWrapper = QueryGenerator.initQueryWrapper(clockInProjectItem, req.getParameterMap());
		Page<ClockInProjectItem> page = new Page<ClockInProjectItem>(pageNo, pageSize);
		IPage<ClockInProjectItem> pageList = clockInProjectItemService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param clockInProjectItem
	 * @return
	 */
	@AutoLog(value = "clock_in_project_item-添加")
	@ApiOperation(value="clock_in_project_item-添加", notes="clock_in_project_item-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ClockInProjectItem clockInProjectItem) {
		clockInProjectItemService.save(clockInProjectItem);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param clockInProjectItem
	 * @return
	 */
	@AutoLog(value = "clock_in_project_item-编辑")
	@ApiOperation(value="clock_in_project_item-编辑", notes="clock_in_project_item-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ClockInProjectItem clockInProjectItem) {
		clockInProjectItemService.updateById(clockInProjectItem);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "clock_in_project_item-通过id删除")
	@ApiOperation(value="clock_in_project_item-通过id删除", notes="clock_in_project_item-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		clockInProjectItemService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "clock_in_project_item-批量删除")
	@ApiOperation(value="clock_in_project_item-批量删除", notes="clock_in_project_item-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.clockInProjectItemService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "clock_in_project_item-通过id查询")
	@ApiOperation(value="clock_in_project_item-通过id查询", notes="clock_in_project_item-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ClockInProjectItem> queryById(@RequestParam(name="id",required=true) String id) {
		ClockInProjectItem clockInProjectItem = clockInProjectItemService.getById(id);
		if(clockInProjectItem==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(clockInProjectItem);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param clockInProjectItem
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ClockInProjectItem clockInProjectItem) {
        return super.exportXls(request, clockInProjectItem, ClockInProjectItem.class, "clock_in_project_item");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ClockInProjectItem.class);
    }

}
