package org.jeecg.modules.clockIntimezone.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.clockIntimezone.entity.ClockInTimeZone;
import org.jeecg.modules.clockIntimezone.service.IClockInTimeZoneService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: clock_in_time_zone
 * @Author: jeecg-boot
 * @Date:   2024-12-10
 * @Version: V1.0
 */
@Api(tags="clock_in_time_zone")
@RestController
@RequestMapping("/clockIntimezone/clockInTimeZone")
@Slf4j
public class ClockInTimeZoneController extends JeecgController<ClockInTimeZone, IClockInTimeZoneService> {
	@Autowired
	private IClockInTimeZoneService clockInTimeZoneService;
	
	/**
	 * 分页列表查询
	 *
	 * @param clockInTimeZone
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "clock_in_time_zone-分页列表查询")
	@ApiOperation(value="clock_in_time_zone-分页列表查询", notes="clock_in_time_zone-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ClockInTimeZone>> queryPageList(ClockInTimeZone clockInTimeZone,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ClockInTimeZone> queryWrapper = QueryGenerator.initQueryWrapper(clockInTimeZone, req.getParameterMap());
		Page<ClockInTimeZone> page = new Page<ClockInTimeZone>(pageNo, pageSize);
		IPage<ClockInTimeZone> pageList = clockInTimeZoneService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param clockInTimeZone
	 * @return
	 */
	@AutoLog(value = "clock_in_time_zone-添加")
	@ApiOperation(value="clock_in_time_zone-添加", notes="clock_in_time_zone-添加")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ClockInTimeZone clockInTimeZone) {
		clockInTimeZoneService.save(clockInTimeZone);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param clockInTimeZone
	 * @return
	 */
	@AutoLog(value = "clock_in_time_zone-编辑")
	@ApiOperation(value="clock_in_time_zone-编辑", notes="clock_in_time_zone-编辑")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ClockInTimeZone clockInTimeZone) {
		clockInTimeZoneService.updateById(clockInTimeZone);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "clock_in_time_zone-通过id删除")
	@ApiOperation(value="clock_in_time_zone-通过id删除", notes="clock_in_time_zone-通过id删除")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		clockInTimeZoneService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "clock_in_time_zone-批量删除")
	@ApiOperation(value="clock_in_time_zone-批量删除", notes="clock_in_time_zone-批量删除")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.clockInTimeZoneService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "clock_in_time_zone-通过id查询")
	@ApiOperation(value="clock_in_time_zone-通过id查询", notes="clock_in_time_zone-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ClockInTimeZone> queryById(@RequestParam(name="id",required=true) String id) {
		ClockInTimeZone clockInTimeZone = clockInTimeZoneService.getById(id);
		if(clockInTimeZone==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(clockInTimeZone);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param clockInTimeZone
    */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ClockInTimeZone clockInTimeZone) {
        return super.exportXls(request, clockInTimeZone, ClockInTimeZone.class, "clock_in_time_zone");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ClockInTimeZone.class);
    }

}
